"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var random_1 = require("./random");
var schnorr = tslib_1.__importStar(require("./schnorr"));
exports.schnorr = schnorr;
var NUM_BYTES = 32;
/**
 * generatePrivateKey
 *
 * @returns {string} - the hex-encoded private key
 */
exports.generatePrivateKey = function () {
    return random_1.randomBytes(NUM_BYTES);
};
/**
 * sign
 *
 * @param {string} hash - hex-encoded hash of the data to be signed
 *
 * @returns {string} the signature
 */
exports.sign = function (msg, privateKey, pubKey) {
    var sig = schnorr.sign(msg, Buffer.from(privateKey, 'hex'), Buffer.from(pubKey, 'hex'));
    var r = sig.r.toString('hex');
    var s = sig.s.toString('hex');
    while (r.length < 64) {
        r = '0' + r;
    }
    while (s.length < 64) {
        s = '0' + s;
    }
    return r + s;
};
tslib_1.__exportStar(require("./util"), exports);
tslib_1.__exportStar(require("./keystore"), exports);
tslib_1.__exportStar(require("./random"), exports);
tslib_1.__exportStar(require("./signature"), exports);
//# sourceMappingURL=index.js.map